@@ -1,5 +1,5 @@
 package Minion::Backend::MongoDB;
-$Minion::Backend::MongoDB::VERSION = '1.04';
+$Minion::Backend::MongoDB::VERSION = '1.05';
 # ABSTRACT: MongoDB backend for Minion
 
 use Mojo::Base 'Minion::Backend';
@@ -293,6 +293,23 @@ sub note {
   return $self->jobs->find_one_and_update(@update) ? 1 : 0;
 }
 
+sub purge {
+    my ($s, $opts) = @_;
+
+    # options keys: queues, states, older, tasks
+    # defaults
+    $opts->{older} //= $s->minion->missing_after;
+
+    my %match;
+    $match{created} = {'$lt' => DateTime->now->add(seconds =>
+        -$opts->{older})};
+    foreach (qw/queue state task/) {
+        $match{$_}   = {'$in' => $opts->{$_.'s'}} if ($opts->{$_.'s'});
+    }
+
+    $s->jobs->delete_many(\%match);
+}
+
 sub receive {
   my ($self, $id) = @_;
   my $oldrec = $self->workers->find_one_and_update(
@@ -381,7 +398,7 @@ sub repair {
 sub reset {
     my ($s, $options) = (shift, shift // {});
     if ($options->{all}) {
-        $_->drop for $s->workers, $s->jobs, $s->locks 
+        $_->drop for $s->workers, $s->jobs, $s->locks
     } elsif ($options->{locks}) {
         $_->drop for $s->{locks};
     } else {
@@ -664,7 +681,7 @@ Minion::Backend::MongoDB - MongoDB backend for Minion
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -1099,6 +1116,51 @@ every other attributes will be pass to L<MongoDB::MongoClient> costructor.
 Change one or more metadata fields for a job. Setting a value to C<undef> will
 remove the field.
 
+=head2 purge
+
+  $backend->purge();
+  $backend->purge({states => ['inactive'], older => 3600});
+
+Purge all jobs created older than...
+
+These options are currently available:
+
+=over 2
+
+=item older
+
+  older => 3600
+
+Value in seconds to purge jobs older than this value.
+
+Default: $minion->missing_after
+
+=item queues
+
+  queues => ['important', 'unimportant']
+
+Purge only jobs in these queues.
+
+=item states
+
+  states => ['inactive', 'failed']
+
+Purge only jobs in these states.
+
+=item tasks
+
+  tasks => ['task1', 'task2']
+
+Purge only jobs for these tasks.
+
+=item queues
+
+  queues => ['q1', 'q2']
+
+Purge only jobs for these queues.
+
+=back
+
 =head2 receive
 
   my $commands = $backend->receive($worker_id);
@@ -1131,6 +1193,7 @@ Repair worker registry and job queue if necessary.
 Reset job queue.
 
 These options are currently available:
+
 =over 2
 
 =item all
